@@ -3,13 +3,13 @@ var searchData=
   ['libcamerabuildpath_0',['libcameraBuildPath',['../utils_8h.html#aa4e149c6ca26755ffd6b448778c4fb63',1,'libcamera::utils']]],
   ['libcamerasourcepath_1',['libcameraSourcePath',['../utils_8h.html#a4163d8b770aad3f746637c59a5f228d2',1,'libcamera::utils']]],
   ['link_2',['link',['../classlibcamera_1_1MediaDevice.html#ab8a926b86f0ae67f56544b10e72cb83f',1,'libcamera::MediaDevice::link(const std::string &amp;sourceName, unsigned int sourceIdx, const std::string &amp;sinkName, unsigned int sinkIdx)'],['../classlibcamera_1_1MediaDevice.html#a84ada727fc400e022fb8814191c54869',1,'libcamera::MediaDevice::link(const MediaEntity *source, unsigned int sourceIdx, const MediaEntity *sink, unsigned int sinkIdx)'],['../classlibcamera_1_1MediaDevice.html#a8ab25ee1197502a3fb2c18d9fbd229a5',1,'libcamera::MediaDevice::link(const MediaPad *source, const MediaPad *sink)']]],
-  ['links_3',['links',['../classlibcamera_1_1MediaPad.html#a34dd306dec37e216abc98c5fba919460',1,'libcamera::MediaPad']]],
+  ['links_3',['links',['../classlibcamera_1_1MediaPad.html#a9e5ea748e528121ea70e03010106b26b',1,'libcamera::MediaPad']]],
   ['load_4',['load',['../classlibcamera_1_1IPAModule.html#a8a092bd638e35b4d3f4ac51f58fe4d51',1,'libcamera::IPAModule']]],
-  ['loadconfiguration_5',['loadConfiguration',['../classlibcamera_1_1Converter.html#a5bf5cd3d555b9c0c0464ee12afdf5679',1,'libcamera::Converter::loadConfiguration()'],['../classlibcamera_1_1V4L2M2MConverter.html#a316322c1f29e1c7a5467480855ae20e8',1,'libcamera::V4L2M2MConverter::loadConfiguration()']]],
+  ['loadconfiguration_5',['loadConfiguration',['../classlibcamera_1_1Converter.html#a9d49d87eced0b64516bf441524f334d1',1,'libcamera::Converter::loadConfiguration()'],['../classlibcamera_1_1V4L2M2MConverter.html#a376f856c62ad7c4c39d8c0997f688f77',1,'libcamera::V4L2M2MConverter::loadConfiguration()'],['../classlibcamera_1_1SoftwareIsp.html#a440e705a54470011b7b0db99f60a8255',1,'libcamera::SoftwareIsp::loadConfiguration()']]],
   ['lock_6',['lock',['../classlibcamera_1_1MediaDevice.html#aafab9ceead67be818337139645d3d9f9',1,'libcamera::MediaDevice']]],
   ['logmessage_7',['LogMessage',['../classlibcamera_1_1LogMessage.html#a4bf00a52f46e00065798c2726ebce5ea',1,'libcamera::LogMessage::LogMessage(const char *fileName, unsigned int line, const LogCategory &amp;category, LogSeverity severity, const std::string &amp;prefix=std::string())'],['../classlibcamera_1_1LogMessage.html#a53182ce9cb5a240d62ea6e3765c15c1c',1,'libcamera::LogMessage::LogMessage(LogMessage &amp;&amp;)']]],
   ['logoutput_8',['LogOutput',['../classlibcamera_1_1LogOutput.html#a488f434ffe6d46d450aed95ad61cd2e4',1,'libcamera::LogOutput::LogOutput(const char *path, bool color)'],['../classlibcamera_1_1LogOutput.html#a1538839b448d23ff5d016094697de800',1,'libcamera::LogOutput::LogOutput(std::ostream *stream, bool color)'],['../classlibcamera_1_1LogOutput.html#a2135b9314eb47dc06162b15f64c13914',1,'libcamera::LogOutput::LogOutput()']]],
-  ['logprefix_9',['logPrefix',['../classlibcamera_1_1Loggable.html#a4cc48b0ae7215ceb4bfae6f192b2b3ee',1,'libcamera::Loggable::logPrefix()'],['../classlibcamera_1_1CameraLens.html#a6291cfc11479b7842cfb209789f7c45c',1,'libcamera::CameraLens::logPrefix()'],['../classlibcamera_1_1CameraSensor.html#a523e12276febd618c890fbb2fcdca9af',1,'libcamera::CameraSensor::logPrefix()'],['../classlibcamera_1_1IPAModule.html#a81b5a10c65b1aeef7218c1b4376ef837',1,'libcamera::IPAModule::logPrefix()'],['../classlibcamera_1_1MediaDevice.html#a15b5bc0dc607109830666d53dfe019e5',1,'libcamera::MediaDevice::logPrefix()'],['../classlibcamera_1_1V4L2Subdevice.html#a41a4a5e9c16871c69ac235545b88346a',1,'libcamera::V4L2Subdevice::logPrefix()'],['../classlibcamera_1_1V4L2VideoDevice.html#a26a10690790249684e707cbfd1d83d77',1,'libcamera::V4L2VideoDevice::logPrefix()'],['../classlibcamera_1_1ipa_1_1ipu3_1_1IPAIPU3.html#a7a4d547cc8ab9165e8149e62c3654f4f',1,'libcamera::ipa::ipu3::IPAIPU3::logPrefix()']]],
+  ['logprefix_9',['logPrefix',['../classlibcamera_1_1Loggable.html#a900bc724d78a3f517d9276784b7db34f',1,'libcamera::Loggable::logPrefix()'],['../classlibcamera_1_1CameraLens.html#a6291cfc11479b7842cfb209789f7c45c',1,'libcamera::CameraLens::logPrefix()'],['../classlibcamera_1_1CameraSensor.html#a523e12276febd618c890fbb2fcdca9af',1,'libcamera::CameraSensor::logPrefix()'],['../classlibcamera_1_1IPAModule.html#a81b5a10c65b1aeef7218c1b4376ef837',1,'libcamera::IPAModule::logPrefix()'],['../classlibcamera_1_1MediaDevice.html#a15b5bc0dc607109830666d53dfe019e5',1,'libcamera::MediaDevice::logPrefix()'],['../classlibcamera_1_1V4L2Subdevice.html#a41a4a5e9c16871c69ac235545b88346a',1,'libcamera::V4L2Subdevice::logPrefix()'],['../classlibcamera_1_1V4L2VideoDevice.html#a26a10690790249684e707cbfd1d83d77',1,'libcamera::V4L2VideoDevice::logPrefix()'],['../classlibcamera_1_1ipa_1_1ipu3_1_1IPAIPU3.html#a7a4d547cc8ab9165e8149e62c3654f4f',1,'libcamera::ipa::ipu3::IPAIPU3::logPrefix()']]],
   ['logsetfile_10',['logSetFile',['../classlibcamera_1_1Logger.html#ac6bd3f563978a790a7a2163b2d511c36',1,'libcamera::Logger::logSetFile()'],['../namespacelibcamera.html#a4fb1124bbbee917f5a29dbe79930f884',1,'libcamera::logSetFile()']]],
   ['logsetlevel_11',['logSetLevel',['../classlibcamera_1_1Logger.html#ac2c8477b8df5f5e11ba04b3851658999',1,'libcamera::Logger::logSetLevel()'],['../namespacelibcamera.html#a1818bc26a0478a661f39f0a54f4894a4',1,'libcamera::logSetLevel()']]],
   ['logsetstream_12',['logSetStream',['../classlibcamera_1_1Logger.html#a1052e5bff4544492c97febd37090343f',1,'libcamera::Logger::logSetStream()'],['../namespacelibcamera.html#a0e15016b52a1d9cf09e21517bf67cb4a',1,'libcamera::logSetStream()']]],
