@@ -6,9 +6,9 @@ var indexSectionsWithContent =
   3: "abcdefghilmoprstuvy",
   4: "_abcdefghijklmnopqrstuvw~",
   5: "abcdefghiklmnopqrstuvwxy",
-  6: "bcdfimopst",
-  7: "acehilmnoprstwy",
-  8: "abcdefghilmnprstuvw",
+  6: "bcdfhimoprst",
+  7: "abcdehilmnoprstwy",
+  8: "abcdefghiklmnoprstuvw",
   9: "o",
   10: "ailr",
   11: "clmst"
